<?php
// $Id$

/**
 * @file
 * Auto shops user page callbacks
 */

/**
 * Callback function for register page
 */
function auto_shops_register_page() {
  return drupal_get_form('auto_shops_register_form');
}

/**
 * Form builder function for register form
 */
function auto_shops_register_form($form_state) {
  global $user;
  $form = array();

  if (empty($form_state['storage'])) {
    $form['stage'] = array('#type' => 'value', '#value' => 1);
    if ((isset($user->mail))) {
      $form['email'] = array(
        '#type' => 'value',
        '#value' => $user->mail,
      );
      $form['display_email'] = array(
        '#type' => 'textfield',
        '#title' => t('email'),
        '#description' => t('your email address'),
        '#value' => $user->mail,
        '#size' => 60,
        '#maxlength' => 128,
        '#disabled' => TRUE,
      );
    }
    else {
      $form['email'] = array(
        '#type' => 'textfield',
        '#title' => t('email'),
        '#description' => t('your email address'),
        '#default_value' => '',
        '#size' => 60,
        '#maxlength' => 128,
        '#required' => TRUE,
      );
    }
    $form['ownership'] = array(
      '#type' => 'select',
      '#title' => t('Shop Owner?'),
      '#description' => t('Are you the owner of a shop?'),
      '#default_value' => 'no',
      '#options' => array(
        'no' => t('No'),
        'yes' => t('Yes'),
      ),
      '#required' => (isset($user->mail)),
    );
    $form['url_own'] = array(
      '#type' => 'textfield',
      '#title' => t('Your Shop URL'),
      '#description' => t('Must begin with http://. If it\'s your shop, your email address must match the same domain ending as your shop URL. Contact us if  there is a problem and we\'ll try and help.'),
      '#default_value' => '',
      '#size' => 60,
      '#maxlength' => 128,
    );
    $form['url_suggest'] = array(
      '#type' => 'textfield',
      '#title' => t('Suggest a Shop?'),
      '#description' => t('Must begin with http://. We like our users to suggest shops to add to yo!Shopper. It\'s optional, so don\'t feel obliged. If you do suggest a shop, we\'re currently building our UK site and we\'ll shortly start building our USA site. You can always suggest a shop later.'),
      '#default_value' => '',
      '#size' => 60,
      '#maxlength' => 128,
    );
    $form['captcha'] = array(
      '#type' => 'captcha',
    );
    $form['submit'] = array('#type' => 'submit', '#value' => t('Next'));
  }
  else {
    // user is logged in, so we are done
    if ($form_state['storage']['user'] == 'authenticated') {
      drupal_set_title('You\'re done!');
      if ($form_state['storage']['url'] != '') { // user suggested url
        $form['return'] = array(
          '#value' => t('Thank you for your submission. You may return to our !homepage now.', array('!homepage' => l('homepage', '<front>'))),
        );
      }
      else {
        $form['return'] = array( // user only registered
          '#value' => t('Thank you for registering. You may return to our !homepage now.', array('!homepage' => l('homepage', '<front>'))),
        );
      }      
    }
    else { // user is not logged in
      $users = db_result(db_query("SELECT COUNT(*) FROM {users} WHERE mail = '%s'", trim($form_state['values']['email'])));
      // user with email address does not seem to exist
      if ($users == 0) {
        drupal_set_title('Nearly there...');
        $form['stage'] = array('#type' => 'value', '#value' => 2);
        $form['first_name'] = array(
          '#type' => 'textfield',
          '#title' => t('First Name'),
          '#description' => t('Because it beats calling you Sir/Madam :)'),
          '#default_value' => '',
          '#size' => 60,
          '#maxlength' => 128,
          '#required' => TRUE,
        );
        $form['password'] = array(
          '#type' => 'password',
          '#title' => t('Password'),
          '#description' => t('Top secret stuff going on here, please keep this safe'),
          '#default_value' => '',
          '#size' => 60,
          '#maxlength' => 128,
          '#required' => TRUE,
        );
        $form['about'] = array(
          '#type' => 'textarea',
          '#title' => t('Tell us about you'),
          '#description' => t('Totally optional. Helps us know a little about you'),
          '#default_value' => '',
          '#size' => 60,
          '#resizable' => FALSE,
          '#rows' => 3,
          '#maxlength' => 128,
        );
        $form['opt_in'] = array(
          '#type' => 'checkbox',
          '#prefix' => '<div id="registration-opt-block">',
          '#title' => t('Yes, I would you like to receive tips, news of new features, and other relevant information.'),
          '#suffix' => '<div class="clear"></div>',
        );
        //$form['back'] = array('#type' => 'submit', '#value' => t('Back'), '#submit' => 'auto_shops_register_form_back');
        // fetch terms and conditions from db
        $terms_and_conditions = db_result(db_query("SELECT body FROM {node_revisions} WHERE nid=4 ORDER BY timestamp DESC LIMIT 1")); // nid hard-coded to terms and conditions node with content
        $form['terms'] = array(
          '#type' => 'textarea',
          '#title' => t('Please read the terms and indicate that you accept them to continue with the registration process. By clicking \'I accept\' below you are agreeing to the terms and conditions below.'),
          '#default_value' => drupal_html_to_text($terms_and_conditions),
          '#size' => 80,
          '#resizable' => FALSE,
          '#disabled' => TRUE,
          '#suffix' => l('Printable Version', 'terms', array('attributes' => array('target' => '_blank'))) .'</div>',
          '#rows' => 4,
        );
        $form['submit'] = array(
          '#type' => 'submit',
          '#value' => t('I accept. Continue with registration'), 
          '#attributes' => array('class' => 'btn-xlg')
        );      
      }
      else { // it seems this user already exists, at least the email is taken. prompt for log in.
        drupal_set_title('Welcome to yo!Shopper, please log in');
        $form['stage'] = array('#type' => 'value', '#value' => 3);
        $form['user_email'] = array(
          '#type' => 'textfield',
          '#title' => t('email'),
          '#value' => $form_state['values']['email'],
          '#description' => t('your email address'),
          '#size' => 60,
          '#disabled' => TRUE,
          '#maxlength' => 128,
          '#required' => TRUE,
        );
        $form['password'] = array(
          '#type' => 'password',
          '#title' => t('Password'),
          '#description' => t('your account password'),
          '#default_value' => '',
          '#size' => 60,
          '#maxlength' => 128,
          '#required' => TRUE,
        );
        //$form['back'] = array('#type' => 'submit', '#value' => t('Back'), '#submit' => 'auto_shops_register_form_back');
        $form['submit'] = array('#type' => 'submit', '#value' => t('Submit'));
      }
    }

  }
  
  return $form;
}

/**
 * Validation handler for register form
 */
function auto_shops_register_form_validate($form, &$form_state) {
  if ($form_state['values']['stage'] == 1) {
    global $user;
    // validate email
    if (!valid_email_address($form_state['values']['email'])) {
      form_set_error('email', t('Please enter a valid email address.'));
    }
    // validate url if present
    if ($form_state['values']['ownership'] == 'yes' && trim($form_state['values']['url_own']) != '' && !valid_url($form_state['values']['url_own'], TRUE)) {
      form_set_error('url_own', t('Please enter a valid url. It should begin with http://'));
    }
    if ($form_state['values']['ownership'] == 'no' && trim($form_state['values']['url_suggest']) != '' && !valid_url($form_state['values']['url_suggest'], TRUE)) {
      form_set_error('url_suggest', t('Please enter a valid url. It should begin with http://'));
    }
    // validate ownership
    if ($form_state['values']['ownership'] == 'yes') {
      $ownership = auto_shops_check_ownership(trim($form_state['values']['url_own']), trim($form_state['values']['email']));
      if (!$ownership) {
        form_set_error('url_own', t('The shop domain must match the domain of the email address for you to be considered the owner.'));
      }
    }
    // if user is not registering, they must suggest a url or what is the point of this form?
    $url1 = trim($form_state['values']['url_suggest']);
    $url2 = trim($form_state['values']['url_own']);
    $users = db_result(db_query("SELECT COUNT(*) FROM {users} WHERE mail = '%s'", trim($form_state['values']['email'])));
    if (($user->uid > 0 && empty($url1) && empty($url2)) || (trim($form_state['values']['email']) != '' && $users != 0 && empty($url1) && empty($url2))) {
      $element = ($form_state['values']['ownership'] == 'yes') ? 'url_own' : 'url_suggest';
      form_set_error($element, t('This email address may already be registered. Please !login or suggest a url to continue.', array('!login' => l(t('login'), 'user/login'))));
    }
    // standardize url format as best as possible
    if ($url1 != '') {
      form_set_value($form['url_suggest'], auto_shops_standardize_url($url1), $form_state);
    }
    if ($url2 != '') {
      form_set_value($form['url_own'], auto_shops_standardize_url($url2), $form_state);
    }
  }
  elseif ($form_state['values']['stage'] == 2) {
    // drupal doesn't require checkboxes even if required attribute set
    // terms and conditions checkbox no longer present
    // if (!$form_state['values']['terms']) {
      // form_set_error('terms', t('You must agree to the yo!Shopper terms and conditions.'));
    // }
  }
}

/**
 * Submit handler for register form
 */

function auto_shops_register_form_submit($form, &$form_state) {
  global $user;
  //drupal_set_message($form_state['values']['url_suggest']);
  //drupal_set_message($form_state['values']['url_own']);
  $form_state['rebuild'] = TRUE;
  $form_state['storage']['user'] = ($user->uid > 0) ? 'authenticated' : 'anonymous';
  if ($form_state['values']['stage'] == 1 && $form_state['storage']['user'] == 'authenticated') {
    $url = ($form_state['values']['ownership'] == 'yes') ? $form_state['values']['url_own'] : $form_state['values']['url_suggest'];
    $form_state['storage']['url'] = trim($url);
    auto_shops_add_and_process($user, $form_state['values']['ownership'], $url);
  }
  elseif ($form_state['values']['stage'] == 1) {
    $form_state['storage']['url'] = ($form_state['values']['ownership'] == 'yes') ? trim($form_state['values']['url_own']) : trim($form_state['values']['url_suggest']);
    $form_state['storage']['ownership'] = $form_state['values']['ownership'];
    $form_state['storage']['email'] = $form_state['values']['email'];
  }
  elseif ($form_state['values']['stage'] == 2) {
    // create user
    $values = array();
    $values['values']['name'] = $form_state['storage']['email'];
    $values['values']['mail'] = $form_state['storage']['email'];
    $values['values']['pass']= $form_state['values']['password'];
    $values['values']['profile_firstname'] = $form_state['values']['first_name'];
    $values['values']['profile_about'] = $form_state['values']['about'];
    $values['values']['terms_of_use'] = 1;
    $values['values']['op'] = t('Create new account');
    $errors = drupal_execute('user_register', $values);
    if ($errors) {
      drupal_set_message('An error was encountered creating your account. Please try again or contact us.', 'error');
      return;
    }
    $account = user_load(array('mail' => $form_state['storage']['email']));
    //drupal_set_message('here:'. print_r($account, 1));
    // user may have provided a url suggestion
    if ($form_state['storage']['url'] != '') {
      // need to save it in the user object so that when user is verified, we can process url suggestion
      user_save($account, array('first_time_login' => 1, 'suggested_url' => $form_state['storage']['url'], 'suggested_url_ownership' => $form_state['storage']['ownership'])); 
    }
    // save opt_in if user agreed to receive mail
    if ($form_state['values']['opt_in']) {
      user_save($account, array('opt_in' => 1));
    }
    $form_state['storage']['user'] = 'authenticated';
  }
  elseif ($form_state['values']['stage'] == 3) {
    // log in user
    $values['values']['name'] = $form_state['storage']['email'];
    $values['values']['pass'] = $form_state['values']['password'];
    $errors = drupal_execute('user_login', $values);
    if ($errors) {
      drupal_set_message('An error was encountered logging in. Please try again or contact us.', 'error');
      return;
    }
    // user may have provided a url suggestion
    if ($form_state['storage']['url'] != '') { 
      auto_shops_add_and_process($user, $form_state['storage']['ownership'], $form_state['storage']['url']);
    }
    $form_state['storage']['user'] = 'authenticated';
  }  
}

// experimental - not in current use 
/*
function auto_shops_register_form_back($form, &$form_state) {
  unset($form_state['storage']);
  $form_state['rebuild'] = TRUE;
}
*/