<?php
// $Id: search-result.tpl.php,v 1.1.2.1 2008/08/28 08:21:44 dries Exp $

/**
 * @file search-result.tpl.php
 * Default theme implementation for displaying a single search result.
 *
 * This template renders a single search result and is collected into
 * search-results.tpl.php. This and the parent template are
 * dependent to one another sharing the markup for definition lists.
 *
 * Available variables:
 * - $url: URL of the result.
 * - $title: Title of the result.
 * - $snippet: A small preview of the result. Does not apply to user searches.
 * - $info: String of all the meta information ready for print. Does not apply
 *   to user searches.
 * - $info_split: Contains same data as $info, split into a keyed array.
 * - $type: The type of search, e.g., "node" or "user".
 *
 * Default keys within $info_split:
 * - $info_split['type']: Node type.
 * - $info_split['user']: Author of the node linked to users profile. Depends
 *   on permission.
 * - $info_split['date']: Last update of the node. Short formatted.
 * - $info_split['comment']: Number of comments output as "% comments", %
 *   being the count. Depends on comment.module.
 * - $info_split['upload']: Number of attachments output as "% attachments", %
 *   being the count. Depends on upload.module.
 *
 * Since $info_split is keyed, a direct print of the item is possible.
 * This array does not apply to user searches so it is recommended to check
 * for their existance before printing. The default keys of 'type', 'user' and
 * 'date' always exist for node searches. Modules may provide other data.
 *
 *   <?php if (isset($info_split['comment'])) : ?>
 *     <span class="info-comment">
 *       <?php print $info_split['comment']; ?>
 *     </span>
 *   <?php endif; ?>
 *
 * To check for all available data within $info_split, use the code below.
 *
 *   <?php print '<pre>'. check_plain(print_r($info_split, 1)) .'</pre>'; ?>
 *
 * @see template_preprocess_search_result()
 */
?>
<?php if (isset($_SESSION['search_results_view']) && $_SESSION['search_results_view'] == 'list') { ?>
  <div class="s-r-node-list">
    <div class="s-r-list-image"><?php $image = $loaded_node->field_screenshot[0]; echo l(theme('imagecache', 'search_result_list', $image['filepath'], $image['data']['alt'], $image['data']['title']), 'node/'. $loaded_node->nid, array('html' => true)); ?></div>
    <div class="s-r-list-info">
      <span class="search-result-fivestar"><?php $current_rating = votingapi_select_results(array('content_id' => $loaded_node->nid, 'function' => 'average')); echo theme('fivestar_static', $current_rating[0]['value'], '5'); ?></span>
      <span class="s-r-list-title"><?php echo l($loaded_node->title .' »', 'node/'. $loaded_node->nid) ?></span><br/><span class="s-r-list-comments"><?php echo $loaded_node->comment_count;?> review<?php echo ($loaded_node->comment_count == 1) ? '' : 's' ?><br/><?php echo flag_create_link('bookmarks', $loaded_node->nid); ?></span>
      <div class="clear"></div>
      <p><?php echo substr($loaded_node->body, 0, 200) .'...'; ?></p>
    </div>
    <div class="clear"></div>
  </div>
<?php } elseif (isset($_SESSION['search_results_view']) && $_SESSION['search_results_view'] == 'grid_large') { ?>
  <div class="search-result-node">
    <span class="search-result-title"><?php echo l($loaded_node->title, 'node/'. $loaded_node->nid) ?></span>
    <span class="search-result-flag"><?php echo flag_create_link('bookmarks', $loaded_node->nid); ?></span>
    <div class="search-result-image"><?php $image = $loaded_node->field_screenshot[0]; echo l(theme('imagecache', 'search_result', $image['filepath'], $image['data']['alt'], $image['data']['title']), 'node/'. $loaded_node->nid, array('html' => true)); ?></div>
    <div class="search-result-info"><span class="search-result-comments"><?php echo $loaded_node->comment_count;?> review<?php echo ($loaded_node->comment_count == 1) ? '' : 's' ?> </span><span class="search-result-fivestar"><?php $current_rating = votingapi_select_results(array('content_id' => $loaded_node->nid, 'function' => 'average')); echo theme('fivestar_static', $current_rating[0]['value'], '5'); ?></span><div class="clear"></div></div>
  </div>
<?php } else { ?>
  <div class="search-result-node">
    <span class="search-result-title"><?php echo l($loaded_node->title, 'node/'. $loaded_node->nid) ?></span>
    <div class="search-result-image"><?php $image = $loaded_node->field_screenshot[0]; echo l(theme('imagecache', 'search_result_small', $image['filepath'], $image['data']['alt'], $image['data']['title']), 'node/'. $loaded_node->nid, array('html' => true)); ?></div>
    <div class="search-result-info"><span class="search-result-comments"><?php echo $loaded_node->comment_count;?> review<?php echo ($loaded_node->comment_count == 1) ? '' : 's' ?> </span><span class="search-result-fivestar"><?php $current_rating = votingapi_select_results(array('content_id' => $loaded_node->nid, 'function' => 'average')); echo theme('fivestar_static', $current_rating[0]['value'], '5'); ?></span><div class="clear"></div></div>
  </div>
<?php } ?>
